@@ -23,8 +23,10 @@
 
 import unittest
 import pandas as pd
-
 from src.dame_formats import DameFormats
+# fix for MacOS using nose
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class TestDameCsv(unittest.TestCase):
@@ -57,6 +59,16 @@ class TestDameCsv(unittest.TestCase):
         n = du.num_columns_in_csv('files/partial.csv')
         self.assertEqual(n, 6)
 
+    def test_is_csv(self):
+        df = DameFormats()
+        file2 = "files/exer1-interface-data.json"
+        self.assertFalse(df.is_csv(file2))
+        file3 = "files/min.commas.csv"
+        self.assertTrue(df.is_csv(file3))
+        self.assertTrue(df.is_csv(file3, delimiter=";"))
+        file4 = "files/min.csv"
+        self.assertTrue(df.is_csv(file4))
+
 
 if __name__ == '__main__':
     unittest.main()
